<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml" xmlns:epub="http://www.idpf.org/2007/ops" xml:lang="zh" lang="zh">

<head>
  <meta charset="utf-8"/>
  <title>Chapter</title>
  <link href="../styles/style.css" rel="stylesheet" type="text/css"/>
</head>

<body>
  {% for item in content %}
  {{ item|safe }}
  {% endfor %}
  {% if citations %}
  <section epub:type="footnotes" role="doc-endnotes">
    {% for item in citations %}
    {{ item|safe }}
    {% endfor %}
  </section>
  {% endif %}
</body>

</html>