blockquote {
 	border-left: 0.15em solid #c7c7c7;
  margin: 0.75em;
  padding: 1em;
 	text-indent:2em;
  line-height:1.5em;
}

a.super {
	font-size: 0.75em;
	vertical-align: super;
}

a.citation {
	font-size: 0.75em;
  font-weight: bold;
	vertical-align: super;
  padding-right: 0.55em;
}

div.citation {
  margin-top: 0.5em;
  margin-left: 0.75em;
  margin-bottom: 1.5em;
}

div.alt-wrapper {
  display: flex;
  flex-direction: column;
  align-items: center;
  padding-top: 0.8em;
  padding-bottom: 3em;
}

div.alt-wrapper table {
  width: 100%;
  table-layout: fixed;
  border-collapse: collapse;
  border-spacing: 0;
  margin: 0;
}

div.alt-wrapper th,
.alt-wrapper td {
  padding: 8px 12px;
  border: 1px solid #e1e4e8;
  text-align: left;
  font-size: 14px;
  line-height: 1.5;
  word-wrap: break-word;
}

div.alt-wrapper th {
  background-color: #f6f8fa;
  font-weight: 600;
}

span.formula-inline {
  display: inline;
  vertical-align: middle;
}

span.formula-inline img {
  display: inline-block;
  vertical-align: middle;
  margin: 0 0.2em;
  max-height: 1.2em;
}