<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml" xmlns:epub="http://www.idpf.org/2007/ops" xml:lang="zh" lang="zh">

<head>
  <meta charset="utf-8"/>
  <title>{{ i18n.cover }}</title>
</head>

<body>
  <p>
    <img src="../assets/cover.png" alt="Cover" />
  </p>
</body>

</html>